@@ -7,22 +7,43 @@ collect_ignore = ['build', 'doc/_build']
 
 rsyncdirs = ['conftest.py', 'bin', 'py', 'doc', 'testing']
 
-import py
+import os, py
+pid = os.getpid()
+
 def pytest_addoption(parser):
     group = parser.getgroup("pylib", "py lib testing options")
-    group.addoption('--sshhost', 
+    group.addoption('--sshhost',
            action="store", dest="sshhost", default=None,
            help=("ssh xspec for ssh functional tests. "))
     group.addoption('--runslowtests',
            action="store_true", dest="runslowtests", default=False,
            help=("run slow tests"))
+    group.addoption('--lsof',
+           action="store_true", dest="lsof", default=False,
+           help=("run FD checks if lsof is available"))
 
+def pytest_configure(config):
+    if config.getvalue("lsof"):
+        try:
+            out = py.process.cmdexec("lsof -p %d" % pid)
+        except py.process.cmdexec.Error:
+            pass
+        else:
+            config._numfiles = len([x for x in out.split("\n") if "REG" in x])
+
+def pytest_unconfigure(config, __multicall__):
+    if not hasattr(config, '_numfiles'):
+        return
+    __multicall__.execute()
+    out2 = py.process.cmdexec("lsof -p %d" % pid)
+    len2 = len([x for x in out2.split("\n") if "REG" in x])
+    assert len2 < config._numfiles + 7, out2
 
 def pytest_funcarg__sshhost(request):
     val = request.config.getvalue("sshhost")
     if val:
         return val
-    py.test.skip("need --sshhost option") 
+    py.test.skip("need --sshhost option")
 def pytest_generate_tests(metafunc):
     multi = getattr(metafunc.function, 'multi', None)
     if multi is not None:
@@ -31,11 +52,11 @@ def pytest_generate_tests(metafunc):
             for val in l:
                 metafunc.addcall(funcargs={name: val})
     elif 'anypython' in metafunc.funcargnames:
-        for name in ('python2.4', 'python2.5', 'python2.6', 
+        for name in ('python2.4', 'python2.5', 'python2.6',
                      'python2.7', 'python3.1', 'pypy-c', 'jython'):
             metafunc.addcall(id=name, param=name)
 
-# XXX copied from execnet's conftest.py - needs to be merged 
+# XXX copied from execnet's conftest.py - needs to be merged
 winpymap = {
     'python2.7': r'C:\Python27\python.exe',
     'python2.6': r'C:\Python26\python.exe',
@@ -52,7 +73,7 @@ def getexecutable(name, cache={}):
         if executable:
             if name == "jython":
                 import subprocess
-                popen = subprocess.Popen([str(executable), "--version"], 
+                popen = subprocess.Popen([str(executable), "--version"],
                     universal_newlines=True, stderr=subprocess.PIPE)
                 out, err = popen.communicate()
                 if not err or "2.5" not in err:
