@@ -1,5 +1,5 @@
 """
-funcargs and support code for testing py.test's own functionality. 
+funcargs and support code for testing py.test's own functionality.
 """
 
 import py
@@ -53,7 +53,7 @@ class TmpTestdir:
     def __init__(self, request):
         self.request = request
         self._pytest = request.getfuncargvalue("_pytest")
-        # XXX remove duplication with tmpdir plugin 
+        # XXX remove duplication with tmpdir plugin
         basetmp = request.config.ensuretemp("testdir")
         name = request.function.__name__
         for i in range(100):
@@ -105,22 +105,22 @@ class TmpTestdir:
     def chdir(self):
         old = self.tmpdir.chdir()
         if not hasattr(self, '_olddir'):
-            self._olddir = old 
+            self._olddir = old
 
     def _makefile(self, ext, args, kwargs):
         items = list(kwargs.items())
         if args:
-            source = "\n".join(map(str, args))
+            source = "\n".join(map(str, args)) + "\n"
             basename = self.request.function.__name__
             items.insert(0, (basename, source))
         ret = None
         for name, value in items:
             p = self.tmpdir.join(name).new(ext=ext)
-            source = py.code.Source(value)
-            p.write(str(py.code.Source(value)).lstrip())
+            source = str(py.code.Source(value)).lstrip()
+            p.write(source.encode("utf-8"), "wb")
             if ret is None:
                 ret = p
-        return ret 
+        return ret
 
 
     def makefile(self, ext, *args, **kwargs):
@@ -140,7 +140,7 @@ class TmpTestdir:
             path = self.tmpdir
         py.std.sys.path.insert(0, str(path))
         self._syspathremove.append(str(path))
-            
+
     def mkdir(self, name):
         return self.tmpdir.mkdir(name)
 
@@ -159,12 +159,12 @@ class TmpTestdir:
         rec = self.getreportrecorder(config)
         colitems = [config.getnode(arg) for arg in config.args]
         items = list(session.genitems(colitems))
-        return items, rec 
+        return items, rec
 
     def runitem(self, source):
-        # used from runner functional tests 
+        # used from runner functional tests
         item = self.getitem(source)
-        # the test class where we are called from wants to provide the runner 
+        # the test class where we are called from wants to provide the runner
         testclassinstance = py.builtin._getimself(self.request.function)
         runner = testclassinstance.getrunner()
         return runner(item)
@@ -181,10 +181,11 @@ class TmpTestdir:
         l = list(args) + [p]
         reprec = self.inline_run(*l)
         reports = reprec.getreports("pytest_runtest_logreport")
-        assert len(reports) == 1, reports 
+        assert len(reports) == 1, reports
         return reports[0]
 
     def inline_run(self, *args):
+        args = ("-s", ) + args # otherwise FD leakage
         config = self.parseconfig(*args)
         config.pluginmanager.do_configure(config)
         session = config.initsession()
@@ -192,7 +193,7 @@ class TmpTestdir:
         colitems = config.getinitialnodes()
         session.main(colitems)
         config.pluginmanager.do_unconfigure(config)
-        return reprec 
+        return reprec
 
     def config_preparse(self):
         config = self.Config()
@@ -201,7 +202,7 @@ class TmpTestdir:
                 config.pluginmanager.import_plugin(plugin)
             else:
                 if isinstance(plugin, dict):
-                    plugin = PseudoPlugin(plugin) 
+                    plugin = PseudoPlugin(plugin)
                 if not config.pluginmanager.isregistered(plugin):
                     config.pluginmanager.register(plugin)
         return config
@@ -212,21 +213,21 @@ class TmpTestdir:
         config = self.config_preparse()
         args = list(args) + ["--basetemp=%s" % self.tmpdir.dirpath('basetemp')]
         config.parse(args)
-        return config 
+        return config
 
     def reparseconfig(self, args=None):
         """ this is used from tests that want to re-invoke parse(). """
         if not args:
             args = [self.tmpdir]
-        from py._test import config 
+        from py._test import config
         oldconfig = config.config_per_process # py.test.config
         try:
             c = config.config_per_process = py.test.config = pytestConfig()
             c.basetemp = oldconfig.mktemp("reparse", numbered=True)
-            c.parse(args) 
+            c.parse(args)
             return c
-        finally: 
-            config.config_per_process = py.test.config = oldconfig 
+        finally:
+            config.config_per_process = py.test.config = oldconfig
 
     def parseconfigure(self, *args):
         config = self.parseconfig(*args)
@@ -238,7 +239,7 @@ class TmpTestdir:
         moditems = modcol.collect()
         for item in modcol.collect():
             if item.name == funcname:
-                return item 
+                return item
         else:
             assert 0, "%r item not found in module:\n%s" %(funcname, source)
 
@@ -246,7 +247,7 @@ class TmpTestdir:
         modcol = self.getmodulecol(source)
         return list(modcol.config.initsession().genitems([modcol]))
         #assert item is not None, "%r item not found in module:\n%s" %(funcname, source)
-        #return item 
+        #return item
 
     def getfscol(self,  path, configargs=()):
         self.config = self.parseconfig(path, *configargs)
@@ -261,9 +262,9 @@ class TmpTestdir:
         self.config = self.parseconfig(path, *configargs)
         self.session = self.config.initsession()
         #self.config.pluginmanager.do_configure(config=self.config)
-        # XXX 
-        self.config.pluginmanager.import_plugin("runner") 
-        plugin = self.config.pluginmanager.getplugin("runner") 
+        # XXX
+        self.config.pluginmanager.import_plugin("runner")
+        plugin = self.config.pluginmanager.getplugin("runner")
         plugin.pytest_configure(config=self.config)
 
         return self.config.getnode(path)
@@ -286,21 +287,26 @@ class TmpTestdir:
         p1 = self.tmpdir.join("stdout")
         p2 = self.tmpdir.join("stderr")
         print_("running", cmdargs, "curdir=", py.path.local())
-        f1 = p1.open("w")
-        f2 = p2.open("w")
+        f1 = p1.open("wb")
+        f2 = p2.open("wb")
         now = time.time()
-        popen = self.popen(cmdargs, stdout=f1, stderr=f2, 
+        popen = self.popen(cmdargs, stdout=f1, stderr=f2,
             close_fds=(sys.platform != "win32"))
         ret = popen.wait()
         f1.close()
         f2.close()
-        out, err = p1.readlines(cr=0), p2.readlines(cr=0)
-        if err:
-            for line in err: 
-                py.builtin.print_(line, file=sys.stderr)
-        if out:
-            for line in out: 
-                py.builtin.print_(line, file=sys.stdout)
+        out = p1.read("rb")
+        out = getdecoded(out).splitlines()
+        err = p2.read("rb")
+        err = getdecoded(err).splitlines()
+        def dump_lines(lines, fp):
+            try:
+                for line in lines:
+                    py.builtin.print_(line, file=fp)
+            except UnicodeEncodeError:
+                print("couldn't print to %s because of encoding" % (fp,))
+        dump_lines(out, sys.stdout)
+        dump_lines(err, sys.stderr)
         return RunResult(ret, out, err, time.time()-now)
 
     def runpybin(self, scriptname, *args):
@@ -315,8 +321,8 @@ class TmpTestdir:
         else:
             cmdlinename = scriptname.replace(".", "")
             assert hasattr(py.cmdline, cmdlinename), cmdlinename
-            source = ("import sys ; sys.path.insert(0, %r); "
-                      "import py ; py.cmdline.%s()" % 
+            source = ("import sys;sys.path.insert(0,%r);"
+                      "import py;py.cmdline.%s()" %
                 (str(py._pydir.dirpath()), cmdlinename))
             return (sys.executable, "-c", source,)
 
@@ -328,7 +334,7 @@ class TmpTestdir:
 
     def _getsysprepend(self):
         if not self.request.config.getvalue("toolsonpath"):
-            s = "import sys ; sys.path.insert(0, %r) ; " % str(py._pydir.dirpath())
+            s = "import sys;sys.path.insert(0,%r);" % str(py._pydir.dirpath())
         else:
             s = ""
         return s
@@ -338,9 +344,14 @@ class TmpTestdir:
         return self.run(py.std.sys.executable, "-c", command)
 
     def runpytest(self, *args):
-        p = py.path.local.make_numbered_dir(prefix="runpytest-", 
+        p = py.path.local.make_numbered_dir(prefix="runpytest-",
             keep=None, rootdir=self.tmpdir)
-        args = ('--basetemp=%s' % p, ) + args 
+        args = ('--basetemp=%s' % p, ) + args
+        for x in args:
+            if '--confcutdir' in str(x):
+                break
+        else:
+            args = ('--confcutdir=.',) + args
         plugins = [x for x in self.plugins if isinstance(x, str)]
         if plugins:
             args = ('-p', plugins[0]) + args
@@ -357,9 +368,16 @@ class TmpTestdir:
         child.timeout = expect_timeout
         return child
 
+def getdecoded(out):
+        try:
+            return out.decode("utf-8")
+        except UnicodeDecodeError:
+            return "INTERNAL not-utf8-decodeable, truncated string:\n%s" % (
+                    py.io.saferepr(out),)
+
 class PseudoPlugin:
     def __init__(self, vars):
-        self.__dict__.update(vars) 
+        self.__dict__.update(vars)
 
 class ReportRecorder(object):
     def __init__(self, hook):
@@ -377,7 +395,7 @@ class ReportRecorder(object):
         """ return list of ParsedCall instances matching the given eventname. """
         return self.hookrecorder.getcalls(names)
 
-    # functionality for test reports 
+    # functionality for test reports
 
     def getreports(self, names="pytest_runtest_logreport pytest_collectreport"):
         return [x.report for x in self.getcalls(names)]
@@ -408,14 +426,14 @@ class ReportRecorder(object):
         skipped = []
         failed = []
         for rep in self.getreports("pytest_runtest_logreport"):
-            if rep.passed: 
-                if rep.when == "call": 
-                    passed.append(rep) 
-            elif rep.skipped: 
-                skipped.append(rep) 
+            if rep.passed:
+                if rep.when == "call":
+                    passed.append(rep)
+            elif rep.skipped:
+                skipped.append(rep)
             elif rep.failed:
-                failed.append(rep) 
-        return passed, skipped, failed 
+                failed.append(rep)
+        return passed, skipped, failed
 
     def countoutcomes(self):
         return [len(x) for x in self.listoutcomes()]
@@ -438,15 +456,16 @@ class LineComp:
         self.stringio = py.io.TextIO()
 
     def assert_contains_lines(self, lines2):
-        """ assert that lines2 are contained (linearly) in lines1. 
+        """ assert that lines2 are contained (linearly) in lines1.
             return a list of extralines found.
         """
         __tracebackhide__ = True
         val = self.stringio.getvalue()
-        self.stringio.truncate(0)  # remove what we got 
+        self.stringio.truncate(0)
+        self.stringio.seek(0)
         lines1 = val.split("\n")
         return LineMatcher(lines1).fnmatch_lines(lines2)
-            
+
 class LineMatcher:
     def __init__(self,  lines):
         self.lines = lines
@@ -461,17 +480,17 @@ class LineMatcher:
             lines2 = lines2.strip().lines
 
         from fnmatch import fnmatch
-        __tracebackhide__ = True
         lines1 = self.lines[:]
         nextline = None
         extralines = []
+        __tracebackhide__ = True
         for line in lines2:
             nomatchprinted = False
             while lines1:
                 nextline = lines1.pop(0)
                 if line == nextline:
                     print_("exact match:", repr(line))
-                    break 
+                    break
                 elif fnmatch(nextline, line):
                     print_("fnmatch:", repr(line))
                     print_("   with:", repr(nextline))
@@ -483,8 +502,4 @@ class LineMatcher:
                     print_("    and:", repr(nextline))
                 extralines.append(nextline)
             else:
-                if line != nextline:
-                    #__tracebackhide__ = True
-                    raise AssertionError("expected line not found: %r" % line)
-        extralines.extend(lines1)
-        return extralines 
+                assert line == nextline
