@@ -1,7 +1,5 @@
 import py
 
-#pytestmark = py.test.mark.skipif("sys.platform.startswith('java')")
-
 def exvalue():
     return py.std.sys.exc_info()[1]
 
@@ -39,7 +37,7 @@ def test_assert_within_finally():
         finally:
             i = 42
     """)
-    s = excinfo.exconly() 
+    s = excinfo.exconly()
     assert s.find("takes no argument") != -1
 
     #def g():
@@ -83,9 +81,9 @@ def test_is():
         s = str(e)
         assert s.startswith("assert 1 is 2")
 
-def test_assert_non_string_message(): 
-    class A: 
-        def __str__(self): 
+def test_assert_non_string_message():
+    class A:
+        def __str__(self):
             return "hello"
     try:
         assert 0 == 1, A()
@@ -106,23 +104,23 @@ def test_assert_keyword_arg():
 class WeirdRepr:
     def __repr__(self):
         return '<WeirdRepr\nsecond line>'
-            
+
 def bug_test_assert_repr():
     v = WeirdRepr()
-    try: 
+    try:
         assert v == 1
     except AssertionError:
         e = exvalue()
         assert e.msg.find('WeirdRepr') != -1
         assert e.msg.find('second line') != -1
         assert 0
-        
+
 def test_assert_non_string():
-    try: 
+    try:
         assert 0, ['list']
     except AssertionError:
         e = exvalue()
-        assert e.msg.find("list") != -1 
+        assert e.msg.find("list") != -1
 
 def test_assert_implicit_multiline():
     try:
@@ -141,6 +139,20 @@ def test_assert_with_brokenrepr_arg():
     if e.msg.find("broken __repr__") == -1:
         py.test.fail("broken __repr__ not handle correctly")
 
+def test_multiple_statements_per_line():
+    try:
+        a = 1; assert a == 2
+    except AssertionError:
+        e = exvalue()
+        assert "assert 1 == 2" in e.msg
+
+def test_power():
+    try:
+        assert 2**3 == 7
+    except AssertionError:
+        e = exvalue()
+        assert "assert (2 ** 3) == 7" in e.msg
+
 
 class TestView:
 
@@ -198,6 +210,10 @@ class TestView:
                 return '%s %s %s' % (self.args[0], self.opname, self.args[1])
 
         codelines = [PyOp(op).generate() for op in existing]
-        assert codelines == ["4 + 5", "getitem('', 'join')", 
+        assert codelines == ["4 + 5", "getitem('', 'join')",
             "setattr('x', 'y', 3)", "12 - 1"]
 
+def test_underscore_api():
+    py.code._AssertionError
+    py.code._reinterpret_old # used by pypy
+    py.code._reinterpret
