@@ -10,7 +10,7 @@ class TestCaptureManager:
         capman = CaptureManager()
         monkeypatch.delattr(os, 'dup', raising=False)
         try:
-            assert capman._getmethod(config, None) == "sys" 
+            assert capman._getmethod(config, None) == "sys"
         finally:
             monkeypatch.undo()
 
@@ -20,9 +20,9 @@ class TestCaptureManager:
         capman = CaptureManager()
         hasfd = hasattr(os, 'dup')
         if hasfd:
-            assert capman._getmethod(config, None) == "fd" 
+            assert capman._getmethod(config, None) == "fd"
         else:
-            assert capman._getmethod(config, None) == "sys" 
+            assert capman._getmethod(config, None) == "sys"
 
         for name in ('no', 'fd', 'sys'):
             if not hasfd and name == 'fd':
@@ -39,6 +39,10 @@ class TestCaptureManager:
         old = sys.stdout, sys.stderr, sys.stdin
         try:
             capman = CaptureManager()
+            # call suspend without resume or start
+            outerr = capman.suspendcapture()
+            outerr = capman.suspendcapture()
+            assert outerr == ("", "")
             capman.resumecapture(method)
             print ("hello")
             out, err = capman.suspendcapture()
@@ -48,10 +52,10 @@ class TestCaptureManager:
                 assert out == "hello\n"
             capman.resumecapture(method)
             out, err = capman.suspendcapture()
-            assert not out and not err 
+            assert not out and not err
         finally:
             capouter.reset()
-      
+
     @needsosdup
     def test_juggle_capturings(self, testdir):
         capouter = py.io.StdCaptureFD()
@@ -80,6 +84,7 @@ def test_capturing_unicode(testdir, method):
     else:
         obj = "u'\u00f6y'"
     testdir.makepyfile("""
+        # coding=utf8
         # taken from issue 227 from nosetests
         def test_unicode():
             import sys
@@ -110,7 +115,7 @@ def test_collect_capturing(testdir):
     result = testdir.runpytest(p)
     result.stdout.fnmatch_lines([
         "*Captured stdout*",
-        "*collect 13 failure*", 
+        "*collect 13 failure*",
     ])
 
 class TestPerTestCapturing:
@@ -153,9 +158,9 @@ class TestPerTestCapturing:
         result = testdir.runpytest(p)
         result.stdout.fnmatch_lines([
             "*test_func():*",
-            "*Captured stdout during setup*", 
-            "module-setup*", 
-            "function-setup*", 
+            "*Captured stdout during setup*",
+            "module-setup*",
+            "function-setup*",
             "*Captured stdout*",
             "in teardown*",
         ])
@@ -171,8 +176,8 @@ class TestPerTestCapturing:
         """)
         result = testdir.runpytest(p)
         s = result.stdout.str()
-        assert "in func1" not in s 
-        assert "in func2" in s 
+        assert "in func1" not in s
+        assert "in func2" in s
 
 
     def test_teardown_capturing(self, testdir):
@@ -182,12 +187,12 @@ class TestPerTestCapturing:
             def teardown_function(function):
                 print ("teardown func1")
                 assert 0
-            def test_func1(): 
+            def test_func1():
                 print ("in func1")
                 pass
         """)
         result = testdir.runpytest(p)
-        assert result.stdout.fnmatch_lines([
+        result.stdout.fnmatch_lines([
             '*teardown_function*',
             '*Captured stdout*',
             "setup func1*",
@@ -205,16 +210,16 @@ class TestPerTestCapturing:
                 pass
         """)
         result = testdir.runpytest(p)
-        assert result.stdout.fnmatch_lines([
-            "*def teardown_module(mod):*", 
-            "*Captured stdout*", 
-            "*teardown module*", 
-            "*1 error*", 
+        result.stdout.fnmatch_lines([
+            "*def teardown_module(mod):*",
+            "*Captured stdout*",
+            "*teardown module*",
+            "*1 error*",
         ])
 
-    def test_capturing_outerr(self, testdir): 
+    def test_capturing_outerr(self, testdir):
         p1 = testdir.makepyfile("""
-            import sys 
+            import sys
             def test_capturing():
                 print (42)
                 sys.stderr.write(str(23))
@@ -225,9 +230,9 @@ class TestPerTestCapturing:
         """)
         result = testdir.runpytest(p1)
         result.stdout.fnmatch_lines([
-            "*test_capturing_outerr.py .F", 
+            "*test_capturing_outerr.py .F",
             "====* FAILURES *====",
-            "____*____", 
+            "____*____",
             "*test_capturing_outerr.py:8: ValueError",
             "*--- Captured stdout ---*",
             "1",
@@ -248,36 +253,6 @@ class TestLoggingInteraction:
         result = testdir.runpytest(p)
         result.stderr.str().find("atexit") == -1
 
-    def test_capturing_and_logging_fundamentals(self, testdir):
-        # here we check a fundamental feature 
-        p = testdir.makepyfile("""
-            import sys, os
-            import py, logging
-            if hasattr(os, 'dup'):
-                cap = py.io.StdCaptureFD(out=False, in_=False)
-            else:
-                cap = py.io.StdCapture(out=False, in_=False)
-            logging.warn("hello1")
-            outerr = cap.suspend()
-
-            print ("suspeneded and captured %s" % (outerr,))
-
-            logging.warn("hello2")
-
-            cap.resume()
-            logging.warn("hello3")
-
-            outerr = cap.suspend()
-            print ("suspend2 and captured %s" % (outerr,))
-        """)
-        result = testdir.runpython(p)
-        assert result.stdout.fnmatch_lines([
-            "suspeneded and captured*hello1*",
-            "suspend2 and captured*hello2*WARNING:root:hello3*",
-        ])
-        assert "atexit" not in result.stderr.str()
-        
-           
     def test_logging_and_immediate_setupteardown(self, testdir):
         p = testdir.makepyfile("""
             import logging
@@ -298,8 +273,8 @@ class TestLoggingInteraction:
             s = result.stdout.str()
             result.stdout.fnmatch_lines([
                 "*WARN*hello3",  # errors show first!
-                "*WARN*hello1", 
-                "*WARN*hello2", 
+                "*WARN*hello1",
+                "*WARN*hello2",
             ])
             # verify proper termination
             assert "closed" not in s
@@ -324,14 +299,14 @@ class TestLoggingInteraction:
             s = result.stdout.str()
             result.stdout.fnmatch_lines([
                 "*WARN*hello3",  # errors come first
-                "*WARN*hello1", 
-                "*WARN*hello2", 
+                "*WARN*hello1",
+                "*WARN*hello2",
             ])
             # verify proper termination
             assert "closed" not in s
 
 class TestCaptureFuncarg:
-    def test_std_functional(self, testdir):        
+    def test_std_functional(self, testdir):
         reprec = testdir.inline_runsource("""
             def test_hello(capsys):
                 print (42)
@@ -339,9 +314,9 @@ class TestCaptureFuncarg:
                 assert out.startswith("42")
         """)
         reprec.assertoutcome(passed=1)
-       
-    @needsosdup 
-    def test_stdfd_functional(self, testdir):        
+
+    @needsosdup
+    def test_stdfd_functional(self, testdir):
         reprec = testdir.inline_runsource("""
             def test_hello(capfd):
                 import os
@@ -352,19 +327,19 @@ class TestCaptureFuncarg:
         """)
         reprec.assertoutcome(passed=1)
 
-    def test_partial_setup_failure(self, testdir):        
+    def test_partial_setup_failure(self, testdir):
         p = testdir.makepyfile("""
-            def test_hello(capfd, missingarg):
+            def test_hello(capsys, missingarg):
                 pass
         """)
         result = testdir.runpytest(p)
-        assert result.stdout.fnmatch_lines([
+        result.stdout.fnmatch_lines([
             "*test_partial_setup_failure*",
             "*1 error*",
         ])
 
     @needsosdup
-    def test_keyboardinterrupt_disables_capturing(self, testdir):        
+    def test_keyboardinterrupt_disables_capturing(self, testdir):
         p = testdir.makepyfile("""
             def test_hello(capfd):
                 import os
@@ -373,7 +348,7 @@ class TestCaptureFuncarg:
         """)
         result = testdir.runpytest(p)
         result.stdout.fnmatch_lines([
-            "*KEYBOARD INTERRUPT*"
+            "*KeyboardInterrupt*"
         ])
         assert result.ret == 2
 
@@ -393,12 +368,13 @@ def test_setup_failure_does_not_kill_capturing(testdir):
 def test_fdfuncarg_skips_on_no_osdup(testdir):
     testdir.makepyfile("""
         import os
-        del os.dup
+        if hasattr(os, 'dup'):
+            del os.dup
         def test_hello(capfd):
             pass
     """)
-    result = testdir.runpytest()
+    result = testdir.runpytest("--capture=no")
     result.stdout.fnmatch_lines([
         "*1 skipped*"
     ])
-    
+
