@@ -3,7 +3,7 @@
 # module, class, and instance level
 
 def test_module_and_function_setup(testdir):
-    reprec = testdir.inline_runsource(""" 
+    reprec = testdir.inline_runsource("""
         modlevel = []
         def setup_module(module):
             assert not modlevel
@@ -22,15 +22,15 @@ def test_module_and_function_setup(testdir):
             assert modlevel[0] == 42
             assert test_modlevel.answer == 17
 
-        class TestFromClass: 
+        class TestFromClass:
             def test_module(self):
                 assert modlevel[0] == 42
-                assert not hasattr(test_modlevel, 'answer') 
+                assert not hasattr(test_modlevel, 'answer')
     """)
-    rep = reprec.matchreport("test_modlevel") 
-    assert rep.passed 
-    rep = reprec.matchreport("test_module") 
-    assert rep.passed 
+    rep = reprec.matchreport("test_modlevel")
+    assert rep.passed
+    rep = reprec.matchreport("test_module")
+    assert rep.passed
 
 def test_class_setup(testdir):
     reprec = testdir.inline_runsource("""
@@ -50,7 +50,7 @@ def test_class_setup(testdir):
                 assert self.clslevel == [23]
 
         def test_cleanup():
-            assert not TestSimpleClassSetup.clslevel 
+            assert not TestSimpleClassSetup.clslevel
             assert not TestInheritedClassSetupStillWorks.clslevel
     """)
     reprec.assertoutcome(passed=1+2+1)
@@ -60,48 +60,48 @@ def test_method_setup(testdir):
     reprec = testdir.inline_runsource("""
         class TestSetupMethod:
             def setup_method(self, meth):
-                self.methsetup = meth 
+                self.methsetup = meth
             def teardown_method(self, meth):
-                del self.methsetup 
+                del self.methsetup
 
             def test_some(self):
-                assert self.methsetup == self.test_some 
+                assert self.methsetup == self.test_some
 
             def test_other(self):
                 assert self.methsetup == self.test_other
     """)
     reprec.assertoutcome(passed=2)
-       
+
 def test_method_generator_setup(testdir):
     reprec = testdir.inline_runsource("""
-        class TestSetupTeardownOnInstance: 
+        class TestSetupTeardownOnInstance:
             def setup_class(cls):
-                cls.classsetup = True 
+                cls.classsetup = True
 
             def setup_method(self, method):
-                self.methsetup = method 
+                self.methsetup = method
 
             def test_generate(self):
-                assert self.classsetup 
-                assert self.methsetup == self.test_generate 
+                assert self.classsetup
+                assert self.methsetup == self.test_generate
                 yield self.generated, 5
                 yield self.generated, 2
 
             def generated(self, value):
-                assert self.classsetup 
-                assert self.methsetup == self.test_generate 
+                assert self.classsetup
+                assert self.methsetup == self.test_generate
                 assert value == 5
     """)
     reprec.assertoutcome(passed=1, failed=1)
 
 def test_func_generator_setup(testdir):
-    reprec = testdir.inline_runsource(""" 
+    reprec = testdir.inline_runsource("""
         import sys
 
         def setup_module(mod):
             print ("setup_module")
             mod.x = []
-        
+
         def setup_function(fun):
             print ("setup_function")
             x.append(1)
@@ -109,22 +109,22 @@ def test_func_generator_setup(testdir):
         def teardown_function(fun):
             print ("teardown_function")
             x.pop()
-        
+
         def test_one():
             assert x == [1]
             def check():
                 print ("check")
                 sys.stderr.write("e\\n")
                 assert x == [1]
-            yield check 
+            yield check
             assert x == [1]
     """)
-    rep = reprec.matchreport("test_one", names="pytest_runtest_logreport") 
-    assert rep.passed 
-        
+    rep = reprec.matchreport("test_one", names="pytest_runtest_logreport")
+    assert rep.passed
+
 def test_method_setup_uses_fresh_instances(testdir):
     reprec = testdir.inline_runsource("""
-        class TestSelfState1: 
+        class TestSelfState1:
             memory = []
             def test_hello(self):
                 self.memory.append(self)
@@ -154,7 +154,7 @@ def test_setup_that_skips_calledagain_and_teardown(testdir):
     p = testdir.makepyfile("""
         import py
         def setup_module(mod):
-            py.test.skip("x") 
+            py.test.skip("x")
         def test_function1():
             pass
         def test_function2():
@@ -192,7 +192,7 @@ def test_setup_funcarg_setup_not_called_if_outer_scope_fails(testdir):
         def setup_module(mod):
             raise ValueError(42)
         def pytest_funcarg__hello(request):
-            raise ValueError(43)
+            raise ValueError("xyz43")
         def test_function1(hello):
             pass
         def test_function2(hello):
@@ -206,7 +206,7 @@ def test_setup_funcarg_setup_not_called_if_outer_scope_fails(testdir):
         "*ValueError*42*",
         "*2 error*"
     ])
-    assert "43" not in result.stdout.str()
+    assert "xyz43" not in result.stdout.str()
 
 
 
