@@ -5,5 +5,5 @@ def test_funcarg(testdir):
     item = testdir.getitem("def test_func(tmpdir): pass")
     p = pytest_funcarg__tmpdir(FuncargRequest(item))
     assert p.check()
-    bn = p.basename.strip("0123456789-")
+    bn = p.basename.strip("0123456789")
     assert bn.endswith("test_func")
